@@ -4,11 +4,10 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = 0.02;
+$VERSION = 0.03;
 @ISA = qw/Gedcom::Date/;
 
 use Gedcom::Date;
-use Carp;
 
 sub parse {
     my $class = shift;
@@ -48,6 +47,14 @@ sub gedcom {
     $self->{gedcom};
 }
 
+sub earliest {
+    return DateTime::Infinite::Past->new;
+}
+
+sub latest {
+    return DateTime::Infinite::Future->new;
+}
+
 my %text = (
     en => ['from %0', 'to %1', 'from %0 to %1'],
     nl => ['vanaf %0', 'tot %1', 'van %0 tot %1'],
