@@ -4,12 +4,11 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = 0.02;
+$VERSION = 0.03;
 @ISA = qw/Gedcom::Date/;
 
 use Gedcom::Date;
 use DateTime 0.15;
-use Carp;
 
 my %months = (
     GREGORIAN => [qw/JAN FEB MAR APR MAI JUN JUL AUG SEP OCT NOV DEC/],
@@ -26,9 +25,10 @@ sub parse_datetime {
     return unless exists $months{$cal};
 
     my ($d, $month, $y) =
-        $date =~ /^(?:(?:(\d+)\s+)?(\w+)\s+)(\d+)$/
+        $date =~ /^(?:(?:(\d+)\s+)?(\w+)\s+)?(\d+)$/
         or return;
 
+    my %known = ( d => defined $d, m => defined $month, y => 1 );
     $d ||= 1;   # Handling of incomplete dates is not correct yet
     $month ||= $months{$cal}[0];
 
@@ -41,18 +41,19 @@ sub parse_datetime {
     my $dt = DateTime->new( year => $y, month => $m, day => $d )
         or return;
 
-    return $dt;
+    return $dt, \%known;
 }
 
 sub parse {
     my $class = shift;
     my ($str) = @_;
 
-    my $dt = Gedcom::Date::Simple->parse_datetime($str)
+    my ($dt, $known) = Gedcom::Date::Simple->parse_datetime($str)
         or return;
 
     my $self = bless {
         datetime => $dt,
+        known => $known,
     }, $class;
 
     return $self;
@@ -63,7 +64,14 @@ sub gedcom {
 
     if (!defined $self->{gedcom}) {
         $self->{datetime}->set(locale => 'en');
-        my $str = uc $self->{datetime}->strftime('%d %b %Y');
+        my $str;
+        if ($self->{known}{d}) {
+            $str = uc $self->{datetime}->strftime('%d %b %Y');
+        } elsif ($self->{known}{m}) {
+            $str = uc $self->{datetime}->strftime('%b %Y');
+        } else {
+            $str = $self->{datetime}->strftime('%Y');
+        }
         $str =~ s/\b0+(\d)/$1/g;
         $self->{gedcom} = $str;
     }
@@ -75,30 +83,55 @@ sub from_datetime {
 
     return bless {
                datetime => $dt,
+               known => {d => 1, m => 1, y => 1},
            }, $class;
 }
 
 sub latest {
     my ($self) = @_;
 
-    return $self->{datetime};
+    my $dt = $self->{datetime};
+    if (!$self->{known}{d}) {
+        $dt->truncate(to => 'month')
+           ->add(months => 1)
+           ->subtract(days => 1);
+    } elsif (!$self->{known}{m}) {
+        $dt->truncate(to => 'year')
+           ->add(years => 1)
+           ->subtract(days => 1);
+    }
+
+    return $dt;
 }
 
 sub earliest {
     my ($self) = @_;
 
-    return $self->{datetime};
+    my $dt = $self->{datetime};
+    if (!$self->{known}{d}) {
+        $dt->truncate(to => 'month');
+    } elsif (!$self->{known}{m}) {
+        $dt->truncate(to => 'year');
+    }
+
+    return $dt;
 }
 
 my %text = (
-    en => 'on %0',
-    nl => 'op %0',
+    en => ['on %0', 'in %0', 'in %0'],
+    nl => ['op %0', 'in %0', 'in %0'],
 );
 
 sub text_format {
     my ($self, $lang) = @_;
 
-    return ($text{$lang}, $self);
+    if ($self->{known}{d}) {
+        return ($text{$lang}[0], $self);
+    } elsif ($self->{known}{m}) {
+        return ($text{$lang}[1], $self);
+    } else {
+        return ($text{$lang}[2], $self);
+    }
 }
 
 sub _date_as_text {
@@ -106,8 +139,14 @@ sub _date_as_text {
 
     my $dt = $self->{datetime};
     $dt->set(locale => $locale);
-    $dt->strftime($dt->locale->long_date_format);
 
+    if ($self->{known}{d}) {
+        return $dt->strftime($dt->locale->long_date_format);
+    } elsif ($self->{known}{m}) {
+        return $dt->strftime('%B %Y');
+    } else {
+        return $dt->year;
+    }
 }
 
 1;
